##  Inviting Users
To invite a user to a workspace, follow these steps:
  1. In the user profile menu in the upper-right corner, select Invite User.
![Selecting](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2753ca147a441014ba75ebfb6fd93278_LowRes.png)
Selecting "Invite User" in the User Profile Menu
  2. In the overlay that appears, enter the user’s email address, select a role, then click Invite. You can invite multiple users at once.


![Inviting Users to a Workspace](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274edea37a441014b84efcb66a580792_LowRes.png)
Inviting Users to a Workspace
Invited users receive email invitations to join the workspace.
##  Inviting Users
To invite a user, you need to provide them with access permissions in your IdP. This enables the user to access all workspaces within the organization's SSO domain.
If you enabled the Invite only flow for a workspace during the SSO setup, in addition to granting access permissions in your IdP, you need to invite users through the Invite User option in the user profile menu. If a user is granted access permissions in your IdP but is not explicitly invited, they cannot access the workspace.
